@@ -7,10 +7,10 @@
  *		HAVE_* and WITH_* defines are substituted at
  *		build time by make with values from autoconf.h.
  *
- * Version:	$Id: 9d59394e4e38668881bfd8650184996d8c6eafc1 $
+ * Version:	$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $
  *
  */
-RCSIDH(missing_h, "$Id: 9d59394e4e38668881bfd8650184996d8c6eafc1 $")
+RCSIDH(missing_h, "$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $")
 
 #if 1
 #  include <stdint.h>
@@ -83,6 +83,22 @@ RCSIDH(missing_h, "$Id: 9d59394e4e38668881bfd8650184996d8c6eafc1 $")
 #  endif
 #endif
 
+#if 1
+#  include <openssl/ssl.h>
+#endif
+
+#if 1
+#  include <openssl/hmac.h>
+#endif
+
+#if 1
+#  include <openssl/asn1.h>
+#endif
+
+#if 1
+#  include <openssl/conf.h>
+#endif
+
 /*
  *	Don't look for winsock.h if we're on cygwin.
  */
@@ -436,10 +452,63 @@ uint128_t ntohlll(uint128_t num);
 typedef void(*sig_t)(int);
 #endif
 
+#if 1
+#if !1
+HMAC_CTX *HMAC_CTX_new(void);
+#  endif
+#if !1
+void HMAC_CTX_free(HMAC_CTX *ctx);
+#  endif
+#endif
+
+#if 1
+#if !1
+static inline const unsigned char *ASN1_STRING_get0_data(const ASN1_STRING *x)
+{
+	/*
+	 * Trick the compiler into not issuing the warning on qualifier stripping.
+	 * We know that ASN1_STRING_data doesn't change x, and we're casting
+	 * the return value back to const immediately, so it's OK.
+	 */
+	union {
+		const ASN1_STRING	*c;
+		ASN1_STRING		*nc;
+	} const_strip = {.c = x};
+	return ASN1_STRING_data(const_strip.nc);
+}
+#  endif
+#endif
+
+#if 1
+#if !1
+static inline int CONF_modules_load_file(const char *filename,
+					 const char *appname,
+					 unsigned long flags)
+{
+	(void)filename;
+	(void)flags;
+	return OPENSSL_config(appname);
+}
+#  endif
+#endif
+
 #ifdef __cplusplus
 }
 #endif
 
+#if 1
+#if !1
+size_t SSL_get_client_random(const SSL *s, unsigned char *out, size_t outlen);
+#  endif
+#if !1
+size_t SSL_get_server_random(const SSL *s, unsigned char *out, size_t outlen);
+#  endif
+#if !1
+size_t SSL_SESSION_get_master_key(const SSL_SESSION *s,
+				  unsigned char *out, size_t outlen);
+#  endif
+#endif
+
 /*
  *	Not really missing, but may be submitted as patches
  *	to the talloc project at some point in the future.
